@@ -19,7 +19,7 @@ class KPushButton;
  */
 class ConfigGeneralPage : public ConfigPageBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
