@@ -12,7 +12,7 @@
  */
 class ConfigPageBase : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
