@@ -5,7 +5,7 @@
 #include "replaygainpluginloader.h"
 #include "replaygain.h"
 #include "ripperpluginloader.h"
-#include "config.h"
+#include "configuration.h"
 #include "tagengine.h"
 #include "cdmanager.h"
 #include "logger.h"
@@ -47,26 +47,26 @@ Convert::Convert( Config* _config, TagEngine* _tagEngine, CDManager* _cdManager,
     tagEngine = _tagEngine;
     cdManager = _cdManager;
     fileList = _fileList;
-    connect( fileList, TQT_SIGNAL(convertItem(FileListItem*)),
-               this, TQT_SLOT(add(FileListItem*))
+    connect( fileList, TQ_SIGNAL(convertItem(FileListItem*)),
+               this, TQ_SLOT(add(FileListItem*))
              );
-    connect( fileList, TQT_SIGNAL(stopItem(FileListItem*)),
-               this, TQT_SLOT(stop(FileListItem*))
+    connect( fileList, TQ_SIGNAL(stopItem(FileListItem*)),
+               this, TQ_SLOT(stop(FileListItem*))
              );
-    connect( this, TQT_SIGNAL(finished(FileListItem*,int)),
-               fileList, TQT_SLOT(itemFinished(FileListItem*,int))
+    connect( this, TQ_SIGNAL(finished(FileListItem*,int)),
+               fileList, TQ_SLOT(itemFinished(FileListItem*,int))
              );
-    connect( this, TQT_SIGNAL(rippingFinished(const TQString&)),
-               fileList, TQT_SLOT(rippingFinished(const TQString&))
+    connect( this, TQ_SIGNAL(rippingFinished(const TQString&)),
+               fileList, TQ_SLOT(rippingFinished(const TQString&))
              );
     logger = _logger;
-    connect( this, TQT_SIGNAL(finishedProcess(int,int)),
-               logger, TQT_SLOT(processCompleted(int,int))
+    connect( this, TQ_SIGNAL(finishedProcess(int,int)),
+               logger, TQ_SLOT(processCompleted(int,int))
              );
 
     tUpdateProgressIndicator = new TQTimer( this, "tUpdateProgressIndicator" );
-    connect( tUpdateProgressIndicator, TQT_SIGNAL(timeout()),
-               this, TQT_SLOT(updateProgressIndicator())
+    connect( tUpdateProgressIndicator, TQ_SIGNAL(timeout()),
+               this, TQ_SLOT(updateProgressIndicator())
              );
 }
 
@@ -102,11 +102,11 @@ void Convert::get( ConvertItem* item )
     }
     else {
         item->moveJob = new TDEIO::FileCopyJob( source, destination, -1, false, true, false, false );
-        connect( item->moveJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)),
-                this, TQT_SLOT(moveProgress(TDEIO::Job*,unsigned long))
+        connect( item->moveJob, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)),
+                this, TQ_SLOT(moveProgress(TDEIO::Job*,unsigned long))
                 );
-        connect( item->moveJob, TQT_SIGNAL(result(TDEIO::Job*)),
-                this, TQT_SLOT(moveFinished(TDEIO::Job*))
+        connect( item->moveJob, TQ_SIGNAL(result(TDEIO::Job*)),
+                this, TQ_SLOT(moveFinished(TDEIO::Job*))
                 );
     }
 }
@@ -143,11 +143,11 @@ void Convert::getCorrection( ConvertItem* item )
     }
     else {
         item->moveJob = new TDEIO::FileCopyJob( source, destination, -1, false, true, false, false );
-        connect( item->moveJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)),
-                this, TQT_SLOT(moveProgress(TDEIO::Job*,unsigned long))
+        connect( item->moveJob, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)),
+                this, TQ_SLOT(moveProgress(TDEIO::Job*,unsigned long))
                 );
-        connect( item->moveJob, TQT_SIGNAL(result(TDEIO::Job*)),
-                this, TQT_SLOT(moveFinished(TDEIO::Job*))
+        connect( item->moveJob, TQ_SIGNAL(result(TDEIO::Job*)),
+                this, TQ_SLOT(moveFinished(TDEIO::Job*))
                 );
     }
 }
@@ -177,11 +177,13 @@ void Convert::rip( ConvertItem* item )
         TQString src;
         if( item->fileListItem->track != 0 ) {
             // TODO does it work with cds with less than 10 tracks?
-            src.sprintf( "audiocd:/Wav/Track %02i.wav?device=" + item->fileListItem->device + "&fileNameTemplate=Track %%{number}", item->fileListItem->track );
+            src = TQString("audiocd:/Wav/Track %1.wav?device=%2&fileNameTemplate=Track %%{number}").
+                arg(TQString::number(item->fileListItem->track).rightJustify(2, '0')).
+                arg(item->fileListItem->device);
         }
         else {
             // FIXME implement ripping of full cds
-            src = "audiocd:/Full CD/Full CD.wav?device=" + item->fileListItem->device + "&albumTemplate=Full CD";
+            src = TQString("audiocd:/Full CD/Full CD.wav?device=%1&albumTemplate=Full CD").arg(item->fileListItem->device);
             item->tracks = 1;
         }
         KURL source( src );
@@ -191,11 +193,11 @@ void Convert::rip( ConvertItem* item )
         item->fileListItem->ripping = true;
 
         item->moveJob = new TDEIO::FileCopyJob( source, dest, -1, false, true, false, false );
-        connect( item->moveJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)),
-                   this, TQT_SLOT(moveProgress(TDEIO::Job*,unsigned long))
+        connect( item->moveJob, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)),
+                   this, TQ_SLOT(moveProgress(TDEIO::Job*,unsigned long))
                  );
-        connect( item->moveJob, TQT_SIGNAL(result(TDEIO::Job*)),
-                   this, TQT_SLOT(moveFinished(TDEIO::Job*))
+        connect( item->moveJob, TQ_SIGNAL(result(TDEIO::Job*)),
+                   this, TQ_SLOT(moveFinished(TDEIO::Job*))
                  );
     }
     else {
@@ -206,15 +208,15 @@ void Convert::rip( ConvertItem* item )
         item->convertProcess->clearArguments();
 
         param = TQString();
-        if( plugin->rip.param ) param.append( " " + plugin->rip.param );
-        if( plugin->rip.device ) param.append( " " + plugin->rip.device );
-        if( plugin->rip.overwrite ) param.append( " " + plugin->rip.overwrite );
+        if( !plugin->rip.param.isEmpty() ) param.append( " " + plugin->rip.param );
+        if( !plugin->rip.device.isEmpty() ) param.append( " " + plugin->rip.device );
+        if( !plugin->rip.overwrite.isEmpty() ) param.append( " " + plugin->rip.overwrite );
 
         if( item->fileListItem->track != 0 ) {
-            if( plugin->rip.track ) param.append( " " + plugin->rip.track );
+            if( !plugin->rip.track.isEmpty() ) param.append( " " + plugin->rip.track );
         }
         else {
-            if( plugin->rip.full_disc.param ) param.append( " " + plugin->rip.full_disc.param );
+            if( !plugin->rip.full_disc.param.isEmpty() ) param.append( " " + plugin->rip.full_disc.param );
             item->tracks = cdManager->getTrackCount( item->fileListItem->device );
             item->track = 0;
         }
@@ -464,10 +466,10 @@ void Convert::encode( ConvertItem* item )
         }
     }
 
-    if( item->fileListItem->options.encodingOptions.replaygain.bEnabled && plugin->enc.replaygain.enabled && plugin->enc.replaygain.use && formatItem->internalReplayGain ) {
+    if( item->fileListItem->options.encodingOptions.replaygain.bEnabled && plugin->enc.replaygain.enabled && !plugin->enc.replaygain.use.isEmpty() && formatItem->internalReplayGain ) {
         param.append( " " + plugin->enc.replaygain.use );
     }
-    else if( plugin->enc.replaygain.enabled && plugin->enc.replaygain.avoid ) {
+    else if( plugin->enc.replaygain.enabled && !plugin->enc.replaygain.avoid.isEmpty() ) {
         param.append( " " + plugin->enc.replaygain.avoid );
     }
 
@@ -635,11 +637,11 @@ void Convert::put( ConvertItem* item )
     }
     else {
         item->moveJob = new TDEIO::FileCopyJob( source, destination, -1, false, false, false, false );
-        connect( item->moveJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)),
-                this, TQT_SLOT(moveProgress(TDEIO::Job*,unsigned long))
+        connect( item->moveJob, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)),
+                this, TQ_SLOT(moveProgress(TDEIO::Job*,unsigned long))
                 );
-        connect( item->moveJob, TQT_SIGNAL(result(TDEIO::Job*)),
-                this, TQT_SLOT(moveFinished(TDEIO::Job*))
+        connect( item->moveJob, TQ_SIGNAL(result(TDEIO::Job*)),
+                this, TQ_SLOT(moveFinished(TDEIO::Job*))
                 );
     }
 }
@@ -674,11 +676,11 @@ void Convert::putCorrection( ConvertItem* item )
     }
     else {
         item->moveJob = new TDEIO::FileCopyJob( source, destination, -1, false, false, false, false );
-        connect( item->moveJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)),
-                this, TQT_SLOT(moveProgress(TDEIO::Job*,unsigned long))
+        connect( item->moveJob, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)),
+                this, TQ_SLOT(moveProgress(TDEIO::Job*,unsigned long))
                 );
-        connect( item->moveJob, TQT_SIGNAL(result(TDEIO::Job*)),
-                this, TQT_SLOT(moveFinished(TDEIO::Job*))
+        connect( item->moveJob, TQ_SIGNAL(result(TDEIO::Job*)),
+                this, TQ_SLOT(moveFinished(TDEIO::Job*))
                 );
     }
 }
@@ -955,23 +957,23 @@ void Convert::processOutput( TDEProcess* proc, char* data, int )
 
                 if( outputPattern.find("%p") != -1 ) {
                      outputPattern.replace( "%p", "%i" );
-                     sscanf( data, outputPattern, &iPercent );
+                     sscanf( data, outputPattern.local8Bit().data(), &iPercent );
                 }
                 else if( outputPattern.find("%t") != -1 ) {
                      outputPattern.replace( "%t", "%i" );
-                     sscanf( data, outputPattern, &iTime );
+                     sscanf( data, outputPattern.local8Bit().data(), &iTime );
                      iPercent = iTime * 100 / (*item)->fileListItem->time;
                 }
                 else if( outputPattern.find("%0") != -1 && outputPattern.find("%1") != -1 ) {
                      if( outputPattern.find("%0") < outputPattern.find("%1") ) {
                          outputPattern.replace( "%0", "%i" );
                          outputPattern.replace( "%1", "%i" );
-                         sscanf( data, outputPattern, &iPos, &iNum );
+                         sscanf( data, outputPattern.local8Bit().data(), &iPos, &iNum );
                      }
                      else {
                          outputPattern.replace( "%0", "%i" );
                          outputPattern.replace( "%1", "%i" );
-                         sscanf( data, outputPattern, &iNum, &iPos );
+                         sscanf( data, outputPattern.local8Bit().data(), &iNum, &iPos );
                      }
                      if( iPos != 0 && iNum != 0 ) iPercent = iPos * 100 / iNum;
                 }
@@ -1000,23 +1002,23 @@ void Convert::processOutput( TDEProcess* proc, char* data, int )
 
                 if( outputPattern.find("%p") != -1 ) {
                      outputPattern.replace( "%p", "%i" );
-                     sscanf( data, outputPattern, &iPercent );
+                     sscanf( data, outputPattern.local8Bit().data(), &iPercent );
                 }
                 else if( outputPattern.find("%t") != -1 ) {
                      outputPattern.replace( "%t", "%i" );
-                     sscanf( data, outputPattern, &iTime );
+                     sscanf( data, outputPattern.local8Bit().data(), &iTime );
                      iPercent = iTime * 100 / (*item)->fileListItem->time;
                 }
                 else if( outputPattern.find("%0") != -1 && outputPattern.find("%1") != -1 ) {
                      if( outputPattern.find("%0") < outputPattern.find("%1") ) {
                          outputPattern.replace( "%0", "%i" );
                          outputPattern.replace( "%1", "%i" );
-                         sscanf( data, outputPattern, &iPos, &iNum );
+                         sscanf( data, outputPattern.local8Bit().data(), &iPos, &iNum );
                      }
                      else {
                          outputPattern.replace( "%0", "%i" );
                          outputPattern.replace( "%1", "%i" );
-                         sscanf( data, outputPattern, &iNum, &iPos );
+                         sscanf( data, outputPattern.local8Bit().data(), &iNum, &iPos );
                      }
                      if( iPos != 0 && iNum != 0 ) iPercent = iPos * 100 / iNum;
                 }
@@ -1043,23 +1045,23 @@ void Convert::processOutput( TDEProcess* proc, char* data, int )
                 if( outputPattern.find("%p") != -1 || outputPattern.find("%a") != -1 ) {
                      outputPattern.replace( "%p", "%i" );
                      outputPattern.replace( "%a", "%i" );
-                     sscanf( data, outputPattern, &iPercent );
+                     sscanf( data, outputPattern.local8Bit().data(), &iPercent );
                 }
                 else if( outputPattern.find("%t") != -1 ) {
                      outputPattern.replace( "%t", "%i" );
-                     sscanf( data, outputPattern, &iTime );
+                     sscanf( data, outputPattern.local8Bit().data(), &iTime );
                      iPercent = iTime * 100 / (*item)->fileListItem->time;
                 }
                 else if( outputPattern.find("%0") != -1 && outputPattern.find("%1") != -1 ) {
                      if( outputPattern.find("%0") < outputPattern.find("%1") ) {
                          outputPattern.replace( "%0", "%i" );
                          outputPattern.replace( "%1", "%i" );
-                         sscanf( data, outputPattern, &iPos, &iNum );
+                         sscanf( data, outputPattern.local8Bit().data(), &iPos, &iNum );
                      }
                      else {
                          outputPattern.replace( "%0", "%i" );
                          outputPattern.replace( "%1", "%i" );
-                         sscanf( data, outputPattern, &iNum, &iPos );
+                         sscanf( data, outputPattern.local8Bit().data(), &iNum, &iPos );
                      }
                      if( iPos != 0 && iNum != 0 ) iPercent = iPos * 100 / iNum;
                 }
@@ -1317,14 +1319,14 @@ void Convert::add( FileListItem* item )
 
     // connect convertProcess of our new item with the slots of Convert
     (*newItem)->convertProcess = new TDEProcess();
-    connect( (*newItem)->convertProcess, TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
-               this, TQT_SLOT(processOutput(TDEProcess*,char*,int))
+    connect( (*newItem)->convertProcess, TQ_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
+               this, TQ_SLOT(processOutput(TDEProcess*,char*,int))
              );
-    connect( (*newItem)->convertProcess, TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
-               this, TQT_SLOT(processOutput(TDEProcess*,char*,int))
+    connect( (*newItem)->convertProcess, TQ_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
+               this, TQ_SLOT(processOutput(TDEProcess*,char*,int))
              );
-    connect( (*newItem)->convertProcess, TQT_SIGNAL(processExited(TDEProcess*)),
-               this, TQT_SLOT(processExit(TDEProcess*))
+    connect( (*newItem)->convertProcess, TQ_SIGNAL(processExited(TDEProcess*)),
+               this, TQ_SLOT(processExit(TDEProcess*))
              );
 
     // NOTE the tempInFile is also created if the file is a audio cd track
@@ -1613,3 +1615,4 @@ void Convert::updateProgressIndicator()
 // }
 
 
+#include "convert.moc"
