@@ -17,7 +17,7 @@ class KPushButton;
  */
 class CuesheetEditor : public KDialog
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
