@@ -55,7 +55,7 @@ public:
  */
 class LogViewerList : public TDEListView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
@@ -81,7 +81,7 @@ public:
  */
 class LogViewer : public KDialog
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
