@@ -1,7 +1,7 @@
 
 #include "optionsdetailed.h"
 #include "convertpluginloader.h"
-#include "config.h"
+#include "configuration.h"
 
 #include <tqlayout.h>
 #include <tqlabel.h>
@@ -46,48 +46,48 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
     normalTopBox->addWidget( lConvert, 0, TQt::AlignVCenter );
     cFormat = new KComboBox( normalOptions, "cFormat" );
     normalTopBox->addWidget( cFormat, 0, TQt::AlignVCenter );
-    connect( cFormat, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(formatChanged())
+    connect( cFormat, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(formatChanged())
              );
-    connect( cFormat, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(somethingChanged())
+    connect( cFormat, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(somethingChanged())
              );
     cQualityMode = new KComboBox( normalOptions, "cQualityMode" );
     cQualityMode->setFixedSize( cQualityMode->sizeHint() );
     normalTopBox->addWidget( cQualityMode, 0, TQt::AlignVCenter );
-    connect( cQualityMode, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(qualityModeChanged())
+    connect( cQualityMode, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(qualityModeChanged())
              );
-    connect( cQualityMode, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(somethingChanged())
+    connect( cQualityMode, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(somethingChanged())
              );
     iQuality = new KIntSpinBox( normalOptions, "iQuality" );
     normalTopBox->addWidget( iQuality, 0, TQt::AlignVCenter );
-    connect( iQuality, TQT_SIGNAL(valueChanged(int)),
-               this, TQT_SLOT(qualityChanged())
+    connect( iQuality, TQ_SIGNAL(valueChanged(int)),
+               this, TQ_SLOT(qualityChanged())
              );
-    connect( iQuality, TQT_SIGNAL(valueChanged(int)),
-               this, TQT_SLOT(somethingChanged())
+    connect( iQuality, TQ_SIGNAL(valueChanged(int)),
+               this, TQ_SLOT(somethingChanged())
              );
     cBitrateMode = new KComboBox( normalOptions, "cBitrateMode" );
     TQToolTip::add( cBitrateMode, i18n("vbr - variable bitrate\nabr - average bitrate\ncbr - constant bitrate") );
     normalTopBox->addWidget( cBitrateMode, 0, TQt::AlignVCenter );
-    connect( cBitrateMode, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(bitrateModeChanged())
+    connect( cBitrateMode, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(bitrateModeChanged())
              );
-    connect( cBitrateMode, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(somethingChanged())
+    connect( cBitrateMode, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(somethingChanged())
              );
     normalTopBox->addSpacing( 18 );
 
     cBitrateRangeSwitch = new TQCheckBox( i18n("Bitrate range")+":", normalOptions, "cBitrateRangeSwitch" );
     TQToolTip::add( cBitrateRangeSwitch, i18n("Use it only if, you know what you are doing, you could reduce the quality.") );
     normalTopBox->addWidget( cBitrateRangeSwitch, 0, TQt::AlignVCenter );
-    connect( cBitrateRangeSwitch, TQT_SIGNAL(toggled(bool)),
-               this, TQT_SLOT(bitrateRangeToggled())
+    connect( cBitrateRangeSwitch, TQ_SIGNAL(toggled(bool)),
+               this, TQ_SLOT(bitrateRangeToggled())
              );
-    connect( cBitrateRangeSwitch, TQT_SIGNAL(toggled(bool)),
-               this, TQT_SLOT(somethingChanged())
+    connect( cBitrateRangeSwitch, TQ_SIGNAL(toggled(bool)),
+               this, TQ_SLOT(somethingChanged())
              );
     iMinBitrate = new KIntSpinBox( normalOptions, "iMinBitrate" );
     iMinBitrate->setMinValue( 32 );
@@ -95,8 +95,8 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
     iMinBitrate->setLineStep( 8 );
     iMinBitrate->setValue( 64 );
     normalTopBox->addWidget( iMinBitrate, 0, TQt::AlignVCenter );
-    connect( iMinBitrate, TQT_SIGNAL(valueChanged(int)),
-               this, TQT_SLOT(somethingChanged())
+    connect( iMinBitrate, TQ_SIGNAL(valueChanged(int)),
+               this, TQ_SLOT(somethingChanged())
              );
     lBitrateRangeTo = new TQLabel( "-", normalOptions, "lBitrateRangeTo" );
     normalTopBox->addWidget( lBitrateRangeTo, 0, TQt::AlignVCenter );
@@ -106,8 +106,8 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
     iMaxBitrate->setLineStep( 8 );
     iMaxBitrate->setValue( 192 );
     normalTopBox->addWidget( iMaxBitrate, 0, TQt::AlignVCenter );
-    connect( iMaxBitrate, TQT_SIGNAL(valueChanged(int)),
-               this, TQT_SLOT(somethingChanged())
+    connect( iMaxBitrate, TQ_SIGNAL(valueChanged(int)),
+               this, TQ_SLOT(somethingChanged())
              );
     lBitrateRangeUnit = new TQLabel( "kbps", normalOptions, "lBitrateRangeUnit" );
     normalTopBox->addWidget( lBitrateRangeUnit, 0, TQt::AlignVCenter );
@@ -118,11 +118,11 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
 
     cSamplingrateSwitch = new TQCheckBox( i18n("Resample")+":", normalOptions, "cSamplingrateSwitch" );
     normalMiddleBox->addWidget( cSamplingrateSwitch, 0, TQt::AlignVCenter );
-    connect( cSamplingrateSwitch, TQT_SIGNAL(toggled(bool)),
-               this, TQT_SLOT(samplingrateToggled())
+    connect( cSamplingrateSwitch, TQ_SIGNAL(toggled(bool)),
+               this, TQ_SLOT(samplingrateToggled())
              );
-    connect( cSamplingrateSwitch, TQT_SIGNAL(toggled(bool)),
-               this, TQT_SLOT(somethingChanged())
+    connect( cSamplingrateSwitch, TQ_SIGNAL(toggled(bool)),
+               this, TQ_SLOT(somethingChanged())
              );
     cSamplingrate = new KComboBox( normalOptions, "cSamplingrate" );
     cSamplingrate->setEditable(true);
@@ -137,8 +137,8 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
     cSamplingrate->insertItem("8000");
     cSamplingrate->setCurrentText("44100");
     normalMiddleBox->addWidget( cSamplingrate, 0, TQt::AlignVCenter );
-    connect( cSamplingrate, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(somethingChanged())
+    connect( cSamplingrate, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(somethingChanged())
              );
     lSamplingrateUnit = new TQLabel( "Hz", normalOptions, "lSamplingrateUnit" );
     normalMiddleBox->addWidget( lSamplingrateUnit, 0, TQt::AlignVCenter );
@@ -146,11 +146,11 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
 
     cChannelsSwitch = new TQCheckBox( i18n("Channels")+":", normalOptions, "cChannelsSwitch" );
     normalMiddleBox->addWidget( cChannelsSwitch, 0, TQt::AlignVCenter );
-    connect( cChannelsSwitch, TQT_SIGNAL(toggled(bool)),
-               this, TQT_SLOT(channelsToggled())
+    connect( cChannelsSwitch, TQ_SIGNAL(toggled(bool)),
+               this, TQ_SLOT(channelsToggled())
              );
-    connect( cChannelsSwitch, TQT_SIGNAL(toggled(bool)),
-               this, TQT_SLOT(somethingChanged())
+    connect( cChannelsSwitch, TQ_SIGNAL(toggled(bool)),
+               this, TQ_SLOT(somethingChanged())
              );
     cChannels = new KComboBox( normalOptions, "cChannels" );
 /*    sChannels.append( i18n("Mono") );
@@ -160,8 +160,8 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
     sChannels.append( i18n("Dual Channels") );
     cChannels->insertStringList( sChannels );*/
     normalMiddleBox->addWidget( cChannels, 0, TQt::AlignVCenter );
-    connect( cChannels, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(somethingChanged())
+    connect( cChannels, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(somethingChanged())
              );
     normalMiddleBox->addSpacing( 18 );
 
@@ -170,8 +170,8 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
     TQToolTip::add( cReplayGain, i18n("Add a Replay Gain tag to the converted file.") );
     TQWhatsThis::add( cReplayGain, i18n("Replay Gain is a volume correction technique. A volume difference is calculated and stored in a tag. This way audio players can automatically adjust the volume and the original music data is not modified (like at normalization).") );
     normalMiddleBox->addWidget( cReplayGain, 0, TQt::AlignVCenter );
-    connect( cReplayGain, TQT_SIGNAL(toggled(bool)),
-               this, TQT_SLOT(somethingChanged())
+    connect( cReplayGain, TQ_SIGNAL(toggled(bool)),
+               this, TQ_SLOT(somethingChanged())
              );
     normalMiddleBox->addStretch();
 
@@ -180,19 +180,19 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
 
     outputDirectory = new OutputDirectory( config, normalOptions, "outputDirectory" );
     normalBottomBox->addWidget( outputDirectory, 0, TQt::AlignVCenter );
-    connect( outputDirectory, TQT_SIGNAL(modeChanged(OutputDirectory::Mode)),
-               this, TQT_SLOT(somethingChanged())
+    connect( outputDirectory, TQ_SIGNAL(modeChanged(OutputDirectory::Mode)),
+               this, TQ_SLOT(somethingChanged())
              );
-    connect( outputDirectory, TQT_SIGNAL(directoryChanged(const TQString&)),
-               this, TQT_SLOT(somethingChanged())
+    connect( outputDirectory, TQ_SIGNAL(directoryChanged(const TQString&)),
+               this, TQ_SLOT(somethingChanged())
              );
     normalBottomBox->addSpacing( 18 );
 
     pProfileSave = new TDEToolBarButton( "document-save", 1003, normalOptions, "pProfileSave" );
     TQToolTip::add( pProfileSave, i18n("Save current options as a profile") );
     normalBottomBox->addWidget( pProfileSave, 0, TQt::AlignVCenter );
-    connect( pProfileSave, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(saveProfile())
+    connect( pProfileSave, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(saveProfile())
              );
 
     // advanced options
@@ -209,8 +209,8 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
     advancedTopBox->addWidget( lUserOptionsLabel, 0, TQt::AlignVCenter );
     lUserOptions = new KLineEdit( advancedOptions, "lUserOptions" );
     advancedTopBox->addWidget( lUserOptions, 0, TQt::AlignVCenter );
-    connect( lUserOptions, TQT_SIGNAL(textChanged(const TQString&)),
-               this, TQT_SLOT(somethingChanged())
+    connect( lUserOptions, TQ_SIGNAL(textChanged(const TQString&)),
+               this, TQ_SLOT(somethingChanged())
              );
 
     TQHBoxLayout *advancedMiddleBox = new TQHBoxLayout();
@@ -595,7 +595,7 @@ void OptionsDetailed::qualityModeChanged()
         cBitrateMode->insertStringList( sBitrateMode );
         bitrateModeChanged();
 
-        if( plugin->enc.lossy.quality.help ) {
+        if( !plugin->enc.lossy.quality.help.isEmpty() ) {
             TQString str = plugin->enc.lossy.quality.help;
             str.replace("\\n","<br>");
             TQWhatsThis::add( iQuality, "<p>"+str+"</p>" );
@@ -909,3 +909,4 @@ void OptionsDetailed::toggleAdvancedOptions()
     }
 }
 
+#include "optionsdetailed.moc"
