@@ -1,7 +1,7 @@
 
 #include "optionsrequester.h"
 #include "options.h"
-#include "config.h"
+#include "configuration.h"
 
 #include <tqlayout.h>
 #include <tqlabel.h>
@@ -59,11 +59,11 @@ OptionsRequester::OptionsRequester( Config* config, TQStringList list, TQWidget
     pOk = new KPushButton( iconLoader->loadIcon("apply",TDEIcon::Small), i18n("Ok"), this, "pOk" );
     buttonBox->addWidget( pOk );
 
-    connect( pCancel, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(reject())
+    connect( pCancel, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(reject())
              );
-    connect( pOk, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(okClicked())
+    connect( pOk, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(okClicked())
              );
 
     // delete the icon loader object
@@ -96,3 +96,4 @@ void OptionsRequester::setOutputDirectory( const TQString& directory )
 }
 
 
+#include "optionsrequester.moc"
