@@ -23,7 +23,7 @@ class KPushButton;
  */
 class OptionsSimple : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
