@@ -3,7 +3,7 @@
 #include "filelist.h"
 #include "conversionoptions.h"
 #include "tagengine.h"
-#include "config.h"
+#include "configuration.h"
 
 #include <tqlayout.h>
 #include <tqtooltip.h>
@@ -49,47 +49,47 @@ OutputDirectory::OutputDirectory( Config* _config, TQWidget* parent, const char*
     cMode->insertItem( i18n("Copy directory structure") );
     //TQToolTip::add( cMode, i18n("Output all converted files into...") );
     box->addWidget( cMode );
-    connect( cMode, TQT_SIGNAL(activated(int)),
-               this, TQT_SLOT(modeChangedSlot(int))
+    connect( cMode, TQ_SIGNAL(activated(int)),
+               this, TQ_SLOT(modeChangedSlot(int))
              );
     modeJustChanged = false;
     /*pModeInfo = new TDEToolBarButton( "messagebox_info", 1010, this, "pModeInfo" );
     TQToolTip::add( pModeInfo, i18n("Information about the output mode") );
     box->addWidget( pModeInfo );
-    connect( pModeInfo, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(modeInfo())
+    connect( pModeInfo, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(modeInfo())
              );*/
     pClear = new TDEToolBarButton( "locationbar_erase", 1001, this, "pClear" );
     TQToolTip::add( pClear, i18n("Clear the directory input field") );
     box->addWidget( pClear );
     lDir = new KLineEdit( this, "lDir" );
     box->addWidget( lDir );
-    connect( lDir, TQT_SIGNAL(textChanged(const TQString&)),
-               this, TQT_SLOT(directoryChangedSlot(const TQString&))
+    connect( lDir, TQ_SIGNAL(textChanged(const TQString&)),
+               this, TQ_SLOT(directoryChangedSlot(const TQString&))
              );
-    connect( pClear, TQT_SIGNAL(clicked()),
-               lDir, TQT_SLOT(setFocus())
+    connect( pClear, TQ_SIGNAL(clicked()),
+               lDir, TQ_SLOT(setFocus())
              );
-    connect( pClear, TQT_SIGNAL(clicked()),
-               lDir, TQT_SLOT(clear())
+    connect( pClear, TQ_SIGNAL(clicked()),
+               lDir, TQ_SLOT(clear())
              );
     /*pDirInfo = new TDEToolBarButton( "messagebox_info", 1011, this, "pDirInfo" );
     TQToolTip::add( pDirInfo, i18n("Information about the wildcards") );
     box->addWidget( pDirInfo );
-    connect( pDirInfo, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(dirInfo())
+    connect( pDirInfo, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(dirInfo())
              );*/
     pDirSelect = new TDEToolBarButton( "folder", 1012, this, "pDirSelect" );
     TQToolTip::add( pDirSelect, i18n("Choose an output directory") );
     box->addWidget( pDirSelect );
-    connect( pDirSelect, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(selectDir())
+    connect( pDirSelect, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(selectDir())
              );
     pDirGoto = new TDEToolBarButton( "konqueror", 1013, this, "pDirGoto" );
     TQToolTip::add( pDirGoto, i18n("Open Konqueror with the output directory") );
     box->addWidget( pDirGoto );
-    connect( pDirGoto, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(gotoDir())
+    connect( pDirGoto, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(gotoDir())
              );
 
     // delete the icon loader object
@@ -569,3 +569,4 @@ void OutputDirectory::directoryChangedSlot( const TQString& directory )
         TQString(i18n("Legend")) );
 }*/
 
+#include "outputdirectory.moc"
