@@ -20,7 +20,7 @@ class TDEToolBarButton;
  */
 class OutputDirectory : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     enum Mode {
