@@ -63,7 +63,7 @@ public:
  */
 class RipperPluginLoader : public PluginLoaderBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
