@@ -31,7 +31,7 @@
 #include <kstdaction.h>
 #include <kedittoolbar.h>
 #include <tdemessagebox.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <tdeio/job.h>
 #include <kprocess.h>
 #include <ksystemtray.h>
